--[[
    Script:  spotlight
	Description: Show how to create an animated spot light of the Gideros logo
	Author:  Michael Hartlef
	Contact: mike@fantomgl.com
--]]

local function drawRec(x, y, w, h, bw, bc, ba, fc, fa)
	local shape = Shape.new()
	shape:setLineStyle(bw, bc, ba)
	shape:setFillStyle(Shape.SOLID, fc, fa)
	shape:beginPath()
	shape:moveTo(x, y)
	shape:lineTo(x + w, y)
	shape:lineTo(x + w, y + h)
	shape:lineTo(x, y + h)
	shape:closePath()
	shape:endPath()
	return shape
end

local function drawRec2(x, y, w, h, bw, bc, ba, textr)
	local shape = Shape.new()
	shape:setLineStyle(bw, bc, ba)
	shape:setFillStyle(Shape.TEXTURE, textr)
	shape:beginPath()
	shape:moveTo(x, y)
	shape:lineTo(x + w, y)
	shape:lineTo(x + w, y + h)
	shape:lineTo(x, y + h)
	shape:closePath()
	shape:endPath()
	return shape
end

local textur = Texture.new("blk.png", true, {wrap = Texture.REPEAT})
local omg = drawRec2(-100, -100, 400, 400,1, 0xFF0000, 1, textur)
local omg2 = Sprite.new()
omg2:addChild(omg)

-- Load the mask images
local mask = Bitmap.new(Texture.new("images/maskCircle2.png"))
--local sound = Sound.new("sound/Gideros.wav")
-- Set its anchor point in the center
mask:setAnchorPoint(0.5, 0.5)

-- Scale it up by a factor of 3
mask:setScale(2.5)

-- Position the mask in the middle of the simulator
mask:setPosition(application:getLogicalHeight()/2,application:getLogicalWidth()/2)

--Set its speed and direction values
mask.speedX = 6
mask.speedY = 4
mask.dirX = 1
mask.dirY = 1

    

--Add the mask to the stage
stage:addChild(mask)




-- Add the logo to the stage
--stage:addChild(logo)
stage:addChild(omg2)

--Now set the blend mode
omg2:setBlendMode(Sprite.MULTIPLY)

-- Set the background color of the stage to black
stage:setBackgroundColor(0, 0, 1)

-- Define the onEnterFrame event function. This deals with the positioning of the mask
function onEnterFrame(event)
	-- Get the position of the maks
	local x,y = mask:getPosition()
	-- Calculate the new position
	x = x + (mask.speedX * mask.dirX)
	y = y + (mask.speedY * mask.dirY)
	-- Check if the mask reaches the edges of the canvas and then mirror its movement.
	if x < 0 then
		mask.dirX = 1
		--sound:play()
	end
		
	if x > application:getLogicalHeight() - mask:getHeight() then
		mask.dirX = -1
		--sound:play()
	end

	if y < 0 then
		mask.dirY = 1
	--	sound:play()
	end
		
	if y > application:getLogicalWidth() - mask:getWidth() then
		mask.dirY = -1
	--	sound:play()
	end
	-- Set the new position of the mask
	mask:setPosition(x,y)
end

-- Register an enterFrame event handler function
stage:addEventListener(Event.ENTER_FRAME,onEnterFrame)